@@ -1,6 +1,5 @@
 /* BFD back-end for Intel 386 PECOFF files.
-   Copyright 1995, 1996, 1999, 2001, 2002, 2004, 2005, 2006, 2007
-   Free Software Foundation, Inc.
+   Copyright (C) 1995-2014 Free Software Foundation, Inc.
 
    This file is part of BFD, the Binary File Descriptor library.
 
@@ -22,7 +21,7 @@
 #include "sysdep.h"
 #include "bfd.h"
 
-#define TARGET_SYM 		i386pe_vec
+#define TARGET_SYM 		i386_pe_vec
 #define TARGET_NAME 		"pe-i386"
 #define COFF_WITH_PE
 #define PCRELOFFSET 		TRUE
