@@ -1,7 +1,7 @@
 #! /bin/sh 
 # Embed an SPU ELF executable into a PowerPC object file.
 #
-# Copyright 2006, 2007 Free Software Foundation, Inc.
+# Copyright (C) 2006-2014 Free Software Foundation, Inc.
 #
 # This file is part of GNU Binutils.
 #
@@ -119,6 +119,7 @@ main ()
   toe=`${READELF} -S ${INFILE} | sed -n -e 's, *\[ *\([0-9]*\)\] *\.toe *[PROGN]*BITS *\([0-9a-f]*\).*,\1 \2,p'`
   toe_addr=`echo $toe | sed -n -e 's,.* ,,p'`
   toe=`echo $toe | sed -n -e 's, .*,,p'`
+  has_ea=`${READELF} -S ${INFILE} | sed -n -e 's, *\[ *\([0-9]*\)\] *\._ea *PROGBITS.*,\1,p'`
   # For loaded sections, pick off section number, address, and file offset
   sections=`${READELF} -S ${INFILE} | sed -n -e 's, *\[ *\([0-9]*\)\] *[^ ]* *PROGBITS *\([0-9a-f]*\) *\([0-9a-f]*\).*,\1 \2 \3,p'`
   sections=`echo ${sections}`
@@ -138,20 +139,20 @@ main ()
   #    sections.
   #    Find all _EAR_ symbols in .toe using readelf, sort by address, and
   #    write the address of the corresponding PowerPC symbol in a table
-  #    built in .data.spetoe.  For _EAE_ symbols not in .toe, create
+  #    built in .data.spetoe.  For _EAR_ symbols not in .toe, create
   #    .reloc commands to relocate their location directly.
   # 3. Look for R_SPU_PPU32 and R_SPU_PPU64 relocations in the SPU ELF image
   #    and create .reloc commands for them.
   # 4. Write a struct spe_program_handle to .data.
   # 5. Write a table of _SPUEAR_ symbols.
   ${CC} ${FLAGS} -x assembler-with-cpp -nostartfiles -nostdlib \
-	-Wa,-mbig -Wl,-r -Wl,-x -o ${OUTFILE} - <<EOF
+	-Wa,-mbig -Wa,-noexecstack -Wl,-r -Wl,-x -o ${OUTFILE} - <<EOF
  .section .data.spetoe,"aw",@progbits
  .p2align 7
 __spetoe__:
 `${READELF} -s -W ${INFILE} | grep ' _EAR_' | sort -k 2 | awk \
 'BEGIN { \
-	addr = strtonum ("0x" "'${toe_addr-0}'"); \
+	addr = strtonum ("0x" "'${toe_addr:-0}'"); \
 	split ("'"${sections}"'", s, " "); \
 	for (i = 1; i in s; i += 3) { \
 	    sec_off[s[i]] = strtonum ("0x" s[i+2]) - strtonum ("0x" s[i+1]); \
@@ -213,7 +214,9 @@ $3 ~ /unrecognized:/ { \
 	if (!donedef) { print "#define HAS_RELOCS 1"; donedef = 1; }; \
 } \
 '`
-#if defined (HAS_RELOCS) && (defined (__PIC__) || defined (__PIE__))
+#if ${has_ea:-0}
+ .section .data.speelf,"aw",@progbits
+#elif defined (HAS_RELOCS) && (defined (__PIC__) || defined (__PIE__))
  .section .data.rel.ro.speelf,"a",@progbits
 #else
  .section .rodata.speelf,"a",@progbits
@@ -222,7 +225,7 @@ $3 ~ /unrecognized:/ { \
 __speelf__:
  .incbin "${INFILE}"
 
- .section .data,"aw",@progbits
+ .section .data.spehandle,"aw",@progbits
  .globl ${SYMBOL}
  .type ${SYMBOL}, @object
 # fill in a struct spe_program_handle
