@@ -1,6 +1,5 @@
 /* windint.h -- internal header file for windres program.
-   Copyright 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2005, 2007
-   Free Software Foundation, Inc.
+   Copyright (C) 1997-2014 Free Software Foundation, Inc.
    Written by Kai Tietz, Onevision.
 
    This file is part of GNU Binutils.
@@ -944,6 +943,18 @@ struct __attribute__ ((__packed__)) bin_fixed_versioninfo
 };
 #define BIN_FIXED_VERSIONINFO_SIZE 52
 
+/* A list of string version information.  */
+
+typedef struct rc_ver_stringtable
+{
+  /* Next item.  */
+  struct rc_ver_stringtable *next;
+  /* Language.  */
+  unichar *language;
+  /* Strings.  */
+  struct rc_ver_stringinfo *strings;
+} rc_ver_stringtable;
+
 /* A list of variable version information.  */
 
 typedef struct rc_ver_info
@@ -957,10 +968,8 @@ typedef struct rc_ver_info
     /* StringFileInfo data.  */
     struct
     {
-      /* Language.  */
-      unichar *language;
-      /* Strings.  */
-      struct rc_ver_stringinfo *strings;
+      /* String tables.  */
+      struct rc_ver_stringtable *stringtables;
     } string;
     /* VarFileInfo data.  */
     struct
@@ -1083,6 +1092,6 @@ extern rc_uint_type windres_get_16 (windres_bfd *, const void *, rc_uint_type);
 extern rc_uint_type windres_get_32 (windres_bfd *, const void *, rc_uint_type);
 
 extern void set_windres_bfd (windres_bfd *, bfd *, asection *, rc_uint_type);
-extern void set_windres_bfd_endianess (windres_bfd *, int);
+extern void set_windres_bfd_endianness (windres_bfd *, int);
 
 #endif
