@@ -1,7 +1,5 @@
 /* listing.c - maintain assembly listings
-   Copyright 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000,
-   2001, 2002, 2003, 2005, 2006, 2007, 2008, 2009, 2010
-   Free Software Foundation, Inc.
+   Copyright (C) 1991-2014 Free Software Foundation, Inc.
 
    This file is part of GAS, the GNU Assembler.
 
@@ -90,7 +88,7 @@
                         on a line.  */
 
 #include "as.h"
-#include "obstack.h"
+#include "filenames.h"
 #include "safe-ctype.h"
 #include "input-file.h"
 #include "subsegs.h"
@@ -142,6 +140,12 @@ enum edict_enum
 };
 
 
+struct list_message
+{
+  char *message;
+  struct list_message *next;
+};
+
 /* This structure remembers which line from which file goes into which
    frag.  */
 struct list_info_struct
@@ -169,8 +173,8 @@ struct list_info_struct
   /* High level language source line.  */
   unsigned int hll_line;
 
-  /* Pointer to any error message associated with this line.  */
-  char *message;
+  /* Pointers to linked list of messages associated with this line.  */
+  struct list_message *messages, *last_message;
 
   enum edict_enum edict;
   char *edict_arg;
@@ -231,22 +235,30 @@ listing_message (const char *name, const char *message)
     {
       unsigned int l = strlen (name) + strlen (message) + 1;
       char *n = (char *) xmalloc (l);
+      struct list_message *lm = xmalloc (sizeof *lm);
       strcpy (n, name);
       strcat (n, message);
-      listing_tail->message = n;
+      lm->message = n;
+      lm->next = NULL;
+
+      if (listing_tail->last_message)
+	listing_tail->last_message->next = lm;
+      else
+	listing_tail->messages = lm;
+      listing_tail->last_message = lm;
     }
 }
 
 void
 listing_warning (const char *message)
 {
-  listing_message (_("Warning:"), message);
+  listing_message (_("Warning: "), message);
 }
 
 void
 listing_error (const char *message)
 {
-  listing_message (_("Error:"), message);
+  listing_message (_("Error: "), message);
 }
 
 static file_info_type *
@@ -257,7 +269,7 @@ file_info (const char *file_name)
 
   while (p != (file_info_type *) NULL)
     {
-      if (strcmp (p->filename, file_name) == 0)
+      if (filename_cmp (p->filename, file_name) == 0)
 	return p;
       p = p->next;
     }
@@ -318,7 +330,7 @@ listing_newline (char *ps)
   if (ps == NULL)
     {
       if (line == last_line
-	  && !(last_file && file && strcmp (file, last_file)))
+	  && !(last_file && file && filename_cmp (file, last_file)))
 	return;
 
       new_i = (list_info_type *) xmalloc (sizeof (list_info_type));
@@ -403,7 +415,8 @@ listing_newline (char *ps)
   new_i->line = line;
   new_i->file = file_info (file);
   new_i->next = (list_info_type *) NULL;
-  new_i->message = (char *) NULL;
+  new_i->messages = NULL;
+  new_i->last_message = NULL;
   new_i->edict = EDICT_NONE;
   new_i->hll_file = (file_info_type *) NULL;
   new_i->hll_line = 0;
@@ -537,7 +550,8 @@ buffer_line (file_info_type *file, char *line, unsigned int size)
 
 /* This function rewinds the requested file back to the line requested,
    reads it in again into the buffer provided and then restores the file
-   back to its original location.  */
+   back to its original location.  Returns the buffer pointer upon success
+   or an empty string if an error occurs.  */
 
 static char *
 rebuffer_line (file_info_type *  file,
@@ -546,13 +560,15 @@ rebuffer_line (file_info_type *  file,
 	       unsigned int      size)
 {
   unsigned int count = 0;
-  unsigned int current_line = 1;
+  unsigned int current_line;
   char * p = buffer;
   long pos;
+  long pos2;
   int c;
+  bfd_boolean found = FALSE;
 
   /* Sanity checks.  */
-  if (file == NULL || buffer == NULL || size == 0 || file->linenum <= linenum)
+  if (file == NULL || buffer == NULL || size <= 1 || file->linenum <= linenum)
     return "";
 
   /* Check the cache and see if we last used this file.  */
@@ -580,38 +596,71 @@ rebuffer_line (file_info_type *  file,
     }
 
   /* Remember where we are in the current file.  */
-  pos = ftell (last_open_file);
-
-  /* Go back to the beginning.  */
-  fseek (last_open_file, 0, SEEK_SET);
-
-  /* Skip lines prior to the one we are interested in.  */
-  while (current_line < linenum)
-    {
-      /* fgets only stops on newlines and has a size limit,
-	 so we read one character at a time instead.  */
-      do
-	{
-	  c = fgetc (last_open_file);
-	}
-      while (c != EOF && c != '\n' && c != '\r');
-
-      ++ current_line;
-
-      if (c == '\r' || c == '\n')
-	{
-	  int next = fgetc (last_open_file);
-
-	  /* If '\r' is followed by '\n', swallow that.  Likewise, if '\n'
-	     is followed by '\r', swallow that as well.  */
-	  if ((c == '\r' && next != '\n')
-	      || (c == '\n' && next != '\r'))
-	    ungetc (next, last_open_file);
-	}
-    }
+  pos2 = pos = ftell (last_open_file);
+  if (pos < 3)
+    return "";
+  current_line = file->linenum;
 
   /* Leave room for the nul at the end of the buffer.  */
   size -= 1;
+  buffer[size] = 0;
+
+  /* Increment the current line count by one.
+     This is to allow for the fact that we are searching for the
+     start of a previous line, but we do this by detecting end-of-line
+     character(s) not start-of-line characters.  */
+  ++ current_line;
+
+  while (pos2 > 0 && ! found)
+    {
+      char * ptr;
+
+      /* Move backwards through the file, looking for earlier lines.  */
+      pos2 = (long) size > pos2 ? 0 : pos2 - size;
+      fseek (last_open_file, pos2, SEEK_SET);
+
+      /* Our caller has kindly provided us with a buffer, so we use it.  */
+      if (fread (buffer, 1, size, last_open_file) != size)
+	{
+	  as_warn (_("unable to rebuffer file: %s\n"), file->filename);
+	  return "";
+	}
+
+      for (ptr = buffer + size; ptr >= buffer; -- ptr)
+	{
+	  if (*ptr == '\n')
+	    {
+	      -- current_line;
+
+	      if (current_line == linenum)
+		{
+		  /* We have found the start of the line we seek.  */
+		  found = TRUE;
+
+		  /* FIXME: We could skip the read-in-the-line code
+		     below if we know that we already have the whole
+		     line in the buffer.  */
+
+		  /* Advance pos2 to the newline character we have just located.  */
+		  pos2 += (ptr - buffer);
+
+		  /* Skip the newline and, if present, the carriage return.  */
+		  if (ptr + 1 == buffer + size)
+		    {
+		      ++pos2;
+		      if (fgetc (last_open_file) == '\r')
+			++ pos2;
+		    }
+		  else
+		    pos2 += (ptr[1] == '\r' ? 2 : 1);
+
+		  /* Move the file pointer to this location.  */
+		  fseek (last_open_file, pos2, SEEK_SET);
+		  break;
+		}
+	    }
+	}
+    }
 
   /* Read in the line.  */
   c = fgetc (last_open_file);
@@ -791,6 +840,7 @@ print_lines (list_info_type *list, unsigned int lineno,
   unsigned int octet_in_word = 0;
   char *src = data_buffer;
   int cur;
+  struct list_message *msg;
 
   /* Print the stuff on the first line.  */
   listing_page (list);
@@ -838,8 +888,8 @@ print_lines (list_info_type *list, unsigned int lineno,
 
   emit_line (list, "\t%s\n", string ? string : "");
 
-  if (list->message)
-    emit_line (list, "****  %s\n", list->message);
+  for (msg = list->messages; msg; msg = msg->next)
+    emit_line (list, "****  %s\n", msg->message);
 
   for (lines = 0;
        lines < (unsigned int) listing_lhs_cont_lines
