@@ -1,7 +1,5 @@
 /* subsegs.c - subsegments -
-   Copyright 1987, 1990, 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998,
-   1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2009
-   Free Software Foundation, Inc.
+   Copyright (C) 1987-2014 Free Software Foundation, Inc.
 
    This file is part of GAS, the GNU Assembler.
 
@@ -148,6 +146,15 @@ subseg_get (const char *segname, int force_new)
 {
   segT secptr;
   segment_info_type *seginfo;
+  const char *now_seg_name = (now_seg
+			      ? bfd_get_section_name (stdoutput, now_seg)
+			      : 0);
+
+  if (!force_new
+      && now_seg_name
+      && (now_seg_name == segname
+	  || !strcmp (now_seg_name, segname)))
+    return now_seg;
 
   if (!force_new)
     secptr = bfd_make_section_old_way (stdoutput, segname);
@@ -271,7 +278,7 @@ seg_not_empty_p (segT sec ATTRIBUTE_UNUSED)
 
   if (!seginfo)
     return 0;
-  
+
   for (chain = seginfo->frchainP; chain; chain = chain->frch_next)
     {
       for (frag = chain->frch_root; frag; frag = frag->fr_next)
